@@ -1,4 +1,4 @@
-from neuralflow.config import GPU
+from .config import GPU
 
 if GPU:
     import cupy as np
