@@ -1,4 +1,4 @@
-from neuralflow.gpu import *
+from .gpu import *
 from collections import OrderedDict
 
 
@@ -10,6 +10,16 @@ class BaseOptimizer():
         self.param_grad_dict["weight_x"] = "dwx"
         self.param_grad_dict["weight_h"] = "dwh"
         self.param_grad_dict["bias"] = "db"
+        self.param_grad_dict["gamma"] = "dgamma"
+        self.param_grad_dict["beta"] = "dbeta"
+        self.param_grad_dict["conv1_weight"] = "c1_dw"
+        self.param_grad_dict["conv1_bias"] = "c1_db"
+        self.param_grad_dict["conv2_weight"] = "c2_dw"
+        self.param_grad_dict["conv2_bias"] = "c2_db"
+        self.param_grad_dict["b1_gamma"] = "b1_dgamma"
+        self.param_grad_dict["b1_beta"] = "b1_dbeta"
+        self.param_grad_dict["b2_gamma"] = "b2_dgamma"
+        self.param_grad_dict["b2_beta"] = "b2_dbeta"
 
     def __repr__(self):
         return "Optimizer"
@@ -107,7 +117,7 @@ class AdaGrad(BaseOptimizer):
 
 
 class Adam(BaseOptimizer):
-    def __init__(self, lr=0.001, b1=0.9, b2=0.999, epsilon=1e-8):
+    def __init__(self, lr=0.001, b1=0.9, b2=0.999, epsilon=1e-8, loss_scaling=None):
         super().__init__(lr)
         self.b1 = b1
         self.b2 = b2
@@ -115,6 +125,7 @@ class Adam(BaseOptimizer):
         self.m = None
         self.v = None
         self.iter = 0
+        self.loss_scaling = loss_scaling
 
     def update(self, model):
         if self.m is None:
@@ -143,6 +154,10 @@ class Adam(BaseOptimizer):
                 grad = layer.get_gradient()
                 param_list = list(layer.parameter.keys())
 
+                if self.loss_scaling != None:
+                    for g in grad.keys():
+                        grad[g] *= (1 / self.loss_scaling)
+
                 for param in param_list:
                     # update m, v
                     self.m[layer_name][param] = self.b1 * self.m[layer_name][param] + (1 - self.b1) * grad[
